library(survival)
library(glmnet)
library(prioritylasso)

#################################
###   ELN2017 in categories   ###
#################################

load("data_ELN_cat.RData")

data <- data_ELN_cat[, 2:dim(data_ELN_cat)[2]]
outcome <- data_ELN_cat[,1]
blocks <- list(1:2, 3:10, 11:50, 51:dim(data)[2])



# prioritylasso, cvoffset = F _______________________________________________________

# runif(1, 0, 10^8)
set.seed(38488074)
pl_kat <- prioritylasso(X = data.matrix(data), Y = outcome, family = "cox", type.measure = "deviance", 
                        blocks = blocks, block1.penalization = FALSE, standardize = FALSE)


pl_kat_coeff_unres <- pl_kat$coefficients[pl_kat$coefficients != 0]

save(pl_kat_coeff_unres, file = "pl_kat_coeff_unres.RData")



# prioritylasso, cvoffset = T _______________________________________________________

set.seed(38488074)
pl_kat <- prioritylasso(X = data.matrix(data), Y = outcome, family = "cox", type.measure = "deviance", 
                        blocks = blocks, block1.penalization = FALSE, standardize = FALSE, cvoffset = TRUE)


pl_kat_cvoffset_coeff_unres <- pl_kat$coefficients[pl_kat$coefficients != 0]

save(pl_kat_cvoffset_coeff_unres, file = "pl_kat_cvoffset_coeff_unres.RData")



# lasso _____________________________________________________________________________

set.seed(38488074)
lasso_kat <- cv.glmnet(x = as.matrix(data), y = outcome, family = "cox", type.measure = "deviance",
                       standardize = FALSE)

lasso_kat_coeff <- lasso_kat$glmnet.fit$beta[,lasso_kat$lambda == lasso_kat$lambda.min]
lasso_kat_coeff_unres <- lasso_kat_coeff[lasso_kat_coeff != 0]

save(lasso_kat_coeff_unres, file = "lasso_kat_coeff_unres.RData")



##############################
###   ELN 2017 variables   ###
##############################

load("data_ELN_var.RData")

data <- data_ELN_var[,2:dim(data_ELN_var)[2]]
outcome <- data_ELN_var[,1]
blocks <- list(1:19, 20:27, 28:67, 68:dim(data)[2])



# prioritylasso, cvoffset = F _______________________________________________________

set.seed(38488074)
pl_ELN <- prioritylasso(X = data.matrix(data), Y = outcome, family = "cox", type.measure = "deviance", 
                        blocks = blocks, block1.penalization = TRUE, standardize = FALSE, cvoffset = F)


pl_ELN_coeff_unres <- pl_ELN$coefficients[pl_ELN$coefficients != 0]

save(pl_ELN_coeff_unres, file = "pl_ELN_coeff_unres.RData")



# prioritylasso, cvoffset = T _______________________________________________________

set.seed(38488074)
pl_ELN_cvoffset <- prioritylasso(X = data.matrix(data), Y = outcome, family = "cox", type.measure = "deviance", 
                                 blocks = blocks, block1.penalization = TRUE, standardize = FALSE, cvoffset = T)


pl_ELN_cvoffset_coeff_unres <- pl_ELN_cvoffset$coefficients[pl_ELN_cvoffset$coefficients != 0]

save(pl_ELN_cvoffset_coeff_unres, file = "pl_ELN_cvoffset_coeff_unres.RData")



# lasso _____________________________________________________________________________

set.seed(38488074)
lasso_ELN <- cv.glmnet(x = as.matrix(data), y = outcome, family = "cox", type.measure = "deviance",
                       standardize = FALSE)

lasso_ELN_coeff <- lasso_ELN$glmnet.fit$beta[,lasso_ELN$lambda == lasso_ELN$lambda.min]
lasso_ELN_coeff_unres <- lasso_ELN_coeff[lasso_ELN_coeff != 0]

save(lasso_ELN_coeff_unres, file = "lasso_ELN_coeff_unres.RData")
