library(survival)
library(xlsx)

###__________________________________________________________###
###   preparation of the first dataset (ELN in categories)   ###
###__________________________________________________________###

# load the data

load("train.RData")
rm(pheno)

pheno.train <- read.xlsx("Phenotable_AML_Array_Cohorte_488_patients_03_2017_Readout.xlsx", 1)

# reorder clinical data

all(pheno.train$Array_ID==colnames(mat))
reorderind <- as.numeric(factor(colnames(mat), levels=pheno.train$Array_ID))
pheno.train <- pheno.train[reorderind,]
all(pheno.train$Array_ID==colnames(mat))

pheno.train[pheno.train == "NA"] = NA


#########################
###   define blocks   ###
#########################

###   block 1

ELN2017_2 <- as.numeric(pheno.train$ELN_2017 == 2)
ELN2017_3 <- as.numeric(pheno.train$ELN_2017 == 3)

block1 <- data.frame(ELN2017_2, ELN2017_3)

###   block 2

block2 <- pheno.train[,c(6:9,11:14)]

block2$Age <- as.numeric(block2$Age)
block2$Sex <- factor(block2$Sex, labels = c(0,1))

block2$ECOG <- as.numeric(as.character(block2$ECOG))
ECOGgr1 <- which(is.element(block2$ECOG, c(0,1)))
ECOGgr2 <- which(block2$ECOG >= 2)
block2$ECOG[ECOGgr1] = 0
block2$ECOG[ECOGgr2] = 1
block2$ECOG <- factor(block2$ECOG)

block2$Diagnose[block2$Diagnose == 3] <- 2
block2$Diagnose <- factor(block2$Diagnose, labels = c(0,1))

block2$Leukos <- as.numeric(as.character(block2$Leukos))
block2$LDH <- as.numeric(as.character(block2$LDH)) 
block2$Hb <- as.numeric(as.character(block2$Hb))
block2$Thrombos <- as.numeric(as.character(block2$Thrombos))


###   block 3

block3 <- pheno.train[,c(50:56, 58:60, 62:76, 78, 80:84, 87:95)]
for(i in 1:ncol(block3)){
  block3[,i] <- as.numeric(as.character(block3[,i]))
}


###   block 4

# use only genes that are available in validation data

load("probes.Rdata")
genes <- probes

genes.mat <- rownames(mat)
ind <- which(genes.mat %in% genes)

mat <- mat[ind,]

block4 <- t(mat)


###   outcome

out <- pheno.train[,32:33]
outcome <- Surv(out[,1], out[,2])


###   bind blocks together

data <- cbind(outcome, block1, block2, block3, block4)
dim(data)
# 488 patients


### exclude data with missing values

data <- na.exclude(data)
dim(data)
# 447 patients


###   standardize data

# clinical data

data$Age <- (data$Age - mean(data$Age))/sd(data$Age)
data$Leukos <- (data$Leukos - mean(data$Leukos))/sd(data$Leukos)
data$LDH <- (data$LDH - mean(data$LDH))/sd(data$LDH)
data$Hb <- (data$Hb - mean(data$Hb))/sd(data$Hb)
data$Thrombos <- (data$Thrombos - mean(data$Thrombos))/sd(data$Thrombos)

# gene expression data

mat <- data[,c(52:dim(data)[2])]
mat_mean <- colMeans(mat)
mat_sd <- apply(mat, 2, sd)
mat_data <- sapply(1:ncol(mat), function(i,x,m,s) (x[,i]-m[i])/s[i], x=mat, m=mat_mean, s=mat_sd)
colnames(mat_data) <- colnames(mat)

# final dataset

data_ELN_cat <- cbind(data[,1:51], mat_data)
save(data_ELN_cat, file="data_ELN_cat.RData")


###_______________________________________________________###
###   preparation of the second dataset (ELN variables)   ###
###_______________________________________________________###

# load the data

load("train.RData")
rm(pheno)

pheno.train <- read.xlsx("Phenotable_AML_Array_Cohorte_488_ELN_Var.xlsx", 1)

# reorder clinical data

all(pheno.train$Array_ID==colnames(mat))
reorderind <- as.numeric(factor(colnames(mat), levels=pheno.train$Array_ID))
pheno.train <- pheno.train[reorderind,]
all(pheno.train$Array_ID==colnames(mat))

pheno.train[pheno.train == "NA"] = NA


#########################
###   define blocks   ###
#########################

###   block 1

block1 <- data.frame(pheno.train[,96:dim(pheno.train)[2]])

###   block 2

block2 <- pheno.train[,c(6:9,11:14)]

block2$Age <- as.numeric(block2$Age)
block2$Sex <- factor(block2$Sex, labels = c(0,1))

block2$ECOG <- as.numeric(as.character(block2$ECOG))
ECOGgr1 <- which(is.element(block2$ECOG, c(0,1)))
ECOGgr2 <- which(block2$ECOG >= 2)
block2$ECOG[ECOGgr1] = 0
block2$ECOG[ECOGgr2] = 1
block2$ECOG <- factor(block2$ECOG)

block2$Diagnose[block2$Diagnose == 3] <- 2
block2$Diagnose <- factor(block2$Diagnose, labels = c(0,1))

block2$Leukos <- as.numeric(as.character(block2$Leukos))
block2$LDH <- as.numeric(as.character(block2$LDH)) 
block2$Hb <- as.numeric(as.character(block2$Hb))
block2$Thrombos <- as.numeric(as.character(block2$Thrombos))


###   block 3

block3 <- pheno.train[,c(50:56, 58:60, 62:76, 78, 80:84, 87:95)]


###   block 4

# use only genes that are available in validation data

load("probes.Rdata")
genes <- probes

genes.mat <- rownames(mat)
ind <- which(genes.mat %in% genes)

mat <- mat[ind,]

block4 <- t(mat)


###   outcome   ###

out <- pheno.train[,32:33]
outcome <- Surv(out[,1], out[,2])


###   bind blocks together

data <- cbind(outcome, block1, block2, block3, block4)
dim(data)
# 488 patients


### exclude data with missing values

data <- na.exclude(data)
dim(data)
# 447 patients


###   standardize data

# clinical data

data$Age <- (data$Age - mean(data$Age))/sd(data$Age)
data$Leukos <- (data$Leukos - mean(data$Leukos))/sd(data$Leukos)
data$LDH <- (data$LDH - mean(data$LDH))/sd(data$LDH)
data$Hb <- (data$Hb - mean(data$Hb))/sd(data$Hb)
data$Thrombos <- (data$Thrombos - mean(data$Thrombos))/sd(data$Thrombos)

# gene expression data

mat <- data[,c(69:dim(data)[2])]
mat_mean <- colMeans(mat)
mat_sd <- apply(mat, 2, sd)
mat_data <- sapply(1:ncol(mat), function(i,x,m,s) (x[,i]-m[i])/s[i], x=mat, m=mat_mean, s=mat_sd)
colnames(mat_data) <- colnames(mat)

# final dataset

data_ELN_var <- cbind(data[,1:68], mat_data)
save(data_ELN_var, file="data_ELN_var.RData")